pub struct CliContext {
pub raw: Vec<String>,
pub domain: Option<String>,
pub resource: Option<String>,
pub verb: Option<String>,
pub target: Option<String>,
pub args: Vec<String>,
pub flags: HashMap<String, String>,
}Expand description
CLI execution context after parsing.
Holds the parsed command components and provides ergonomic helpers for flag lookup, output format detection, etc.
Fields
raw: Vec<String>Full argument vector after red
domain: Option<String>Primary command (e.g. “server”, “query”, “health”)
resource: Option<String>Resource within the domain (e.g. collection name)
verb: Option<String>Verb or action to perform
target: Option<String>Optional target (id, query string, etc.)
args: Vec<String>Additional positional arguments beyond the target
flags: HashMap<String, String>Parsed flags (--flag=value, -f value, etc.)
Implementations
Sourceimpl CliContext
impl CliContext
pub fn new() -> CliContext
Sourcepub fn get_flag_or(&self, key: &str, default: &str) -> String
pub fn get_flag_or(&self, key: &str, default: &str) -> String
Get a flag value or return a default.
Sourcepub fn domain_only(&self) -> Option<&str>
pub fn domain_only(&self) -> Option<&str>
Get the domain only (first positional).
Sourcepub fn wants_json(&self) -> bool
pub fn wants_json(&self) -> bool
Check if JSON output was explicitly requested.
Sourcepub fn wants_machine_output(&self) -> bool
pub fn wants_machine_output(&self) -> bool
Check if machine-readable output was requested (JSON or YAML).
Sourcepub fn get_output_format(&self) -> OutputFormat
pub fn get_output_format(&self) -> OutputFormat
Get the output format from flags or default to human.