pub enum PlacementAuthorityError {
EmptyCatalogSlice {
group: CollectionGroupId,
},
DuplicateCollectionGroup {
group: CollectionGroupId,
},
OverlappingCatalogSlice {
collection: CollectionId,
existing_group: CollectionGroupId,
attempted_group: CollectionGroupId,
},
}Expand description
Why a Placement Authority assignment was rejected.
Variants
EmptyCatalogSlice
A group assignment must publish at least one collection in its catalog slice.
Fields

group: CollectionGroupIdDuplicateCollectionGroup
The group already has exactly one Placement Authority.
Fields

group: CollectionGroupIdOverlappingCatalogSlice
Two Placement Authority assignments would own the same collection-catalog slice.
Fields

collection: CollectionId
existing_group: CollectionGroupId
attempted_group: CollectionGroupIdTrait Implementations
Sourceimpl Clone for PlacementAuthorityError
impl Clone for PlacementAuthorityError
Sourcefn clone(&self) -> PlacementAuthorityError
fn clone(&self) -> PlacementAuthorityError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlacementAuthorityError
impl Debug for PlacementAuthorityError
Sourceimpl Display for PlacementAuthorityError
impl Display for PlacementAuthorityError
impl Eq for PlacementAuthorityError
Sourceimpl Error for PlacementAuthorityError
impl Error for PlacementAuthorityError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for PlacementAuthorityError
impl PartialEq for PlacementAuthorityError
Sourcefn eq(&self, other: &PlacementAuthorityError) -> bool
fn eq(&self, other: &PlacementAuthorityError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PlacementAuthorityError