pub struct ArchiveRecoveryRequest { /* private fields */ }Expand description
Request to recover a range from a restored archive seed and move ownership to the recovered target.
Implementations
Sourceimpl ArchiveRecoveryRequest
impl ArchiveRecoveryRequest
pub fn new( collection: CollectionId, range_id: RangeId, target: NodeIdentity, latest_commit_watermark: CommitWatermark, mode: ArchiveRecoveryMode, capability: ForceTransitionCapability, reason: OperatorReason, ) -> ArchiveRecoveryRequest
pub fn with_replicas( self, replicas: impl IntoIterator<Item = NodeIdentity>, ) -> ArchiveRecoveryRequest
pub fn with_restored_archive( self, restored: RestoredArchiveReplica, ) -> ArchiveRecoveryRequest