pub struct ArchivedRangeReplica { /* private fields */ }Expand description
Compressed archive data for one range.
Implementations
Sourceimpl ArchivedRangeReplica
impl ArchivedRangeReplica
pub fn new( collection: CollectionId, range_id: RangeId, archive_id: impl Into<String>, compressed_bytes: Vec<u8>, expected_checksum: u32, covered_watermark: CommitWatermark, ) -> ArchivedRangeReplica
Sourcepub fn restore(&self) -> Result<RestoredArchiveReplica, ArchiveRecoveryError>
pub fn restore(&self) -> Result<RestoredArchiveReplica, ArchiveRecoveryError>
Restore the compressed payload and validate the checksum before it can be used as a recovered range seed.