pub struct DrainBlock {
pub collection: CollectionId,
pub range_id: RangeId,
pub reason: DrainBlockReason,
}Expand description
A range that blocks the drain: it still depends on the draining member and could not be moved.
Fields
collection: CollectionIdrange_id: RangeIdreason: DrainBlockReasonTrait Implementations
Sourceimpl Clone for DrainBlock
impl Clone for DrainBlock
Sourcefn clone(&self) -> DrainBlock
fn clone(&self) -> DrainBlock
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DrainBlock
impl Debug for DrainBlock
impl Eq for DrainBlock
Sourceimpl PartialEq for DrainBlock
impl PartialEq for DrainBlock
Sourcefn eq(&self, other: &DrainBlock) -> bool
fn eq(&self, other: &DrainBlock) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DrainBlock