pub struct ForceRemoveResult {
pub audit: ForceRemoveAudit,
pub promotions: Vec<TransitionOutcome>,
pub unrecoverable: Vec<ForcedBlock>,
pub removed: Option<ClusterMember>,
}Expand description
The result of running a forced removal: the audit evidence, the activated promotion outcomes, the unrecoverable ranges, and the removed member (if it was a member). The dead member is removed from the catalog regardless of unrecoverable ranges — it is gone; the unrecoverable ranges are recorded for the operator, not a reason to keep a dead member listed.
Fields
audit: ForceRemoveAuditpromotions: Vec<TransitionOutcome>unrecoverable: Vec<ForcedBlock>removed: Option<ClusterMember>Trait Implementations
Sourceimpl Clone for ForceRemoveResult
impl Clone for ForceRemoveResult
Sourcefn clone(&self) -> ForceRemoveResult
fn clone(&self) -> ForceRemoveResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ForceRemoveResult
impl Debug for ForceRemoveResult
impl Eq for ForceRemoveResult
Sourceimpl PartialEq for ForceRemoveResult
impl PartialEq for ForceRemoveResult
Sourcefn eq(&self, other: &ForceRemoveResult) -> bool
fn eq(&self, other: &ForceRemoveResult) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ForceRemoveResult