pub struct HotMirrorFailoverEvidence {
pub workflow: &'static str,
pub range: HotMirrorRangeEvidence,
pub previous_owner: NodeIdentity,
pub promoted_owner: NodeIdentity,
pub epoch: HotMirrorEpochEvidence,
pub watermark: CommitWatermark,
pub watermark_outcome: WatermarkOutcome,
}Expand description
Operator-facing result evidence for a successful hot mirror promotion.
Fields
workflow: &'static strrange: HotMirrorRangeEvidenceprevious_owner: NodeIdentitypromoted_owner: NodeIdentityepoch: HotMirrorEpochEvidencewatermark: CommitWatermarkwatermark_outcome: WatermarkOutcomeTrait Implementations
Sourceimpl Clone for HotMirrorFailoverEvidence
impl Clone for HotMirrorFailoverEvidence
Sourcefn clone(&self) -> HotMirrorFailoverEvidence
fn clone(&self) -> HotMirrorFailoverEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HotMirrorFailoverEvidence
impl Debug for HotMirrorFailoverEvidence
impl Eq for HotMirrorFailoverEvidence
Sourceimpl PartialEq for HotMirrorFailoverEvidence
impl PartialEq for HotMirrorFailoverEvidence
Sourcefn eq(&self, other: &HotMirrorFailoverEvidence) -> bool
fn eq(&self, other: &HotMirrorFailoverEvidence) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for HotMirrorFailoverEvidence