pub struct LeaseFenceRejection {
pub reason: FenceReason,
}Expand description
Why a request was refused while the owner is self-fenced.
Fields
reason: FenceReasonThe fence cause that was in effect when the request was refused.