pub struct SkippedDataEvidence {
pub restored_watermark: CommitWatermark,
pub latest_commit_watermark: CommitWatermark,
pub skipped_lsn: u64,
}Expand description
The RPO gap proved by a forced archive recovery whose restored watermark is behind the latest committed watermark.
Fields
restored_watermark: CommitWatermarklatest_commit_watermark: CommitWatermarkskipped_lsn: u64Trait Implementations
Sourceimpl Clone for SkippedDataEvidence
impl Clone for SkippedDataEvidence
Sourcefn clone(&self) -> SkippedDataEvidence
fn clone(&self) -> SkippedDataEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SkippedDataEvidence
Sourceimpl Debug for SkippedDataEvidence
impl Debug for SkippedDataEvidence
impl Eq for SkippedDataEvidence
Sourceimpl PartialEq for SkippedDataEvidence
impl PartialEq for SkippedDataEvidence
Sourcefn eq(&self, other: &SkippedDataEvidence) -> bool
fn eq(&self, other: &SkippedDataEvidence) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SkippedDataEvidence