YamlConfig

Struct YamlConfig 

pub struct YamlConfig {
Show 30 fields pub verbose: Option<bool>, pub no_color: Option<bool>, pub output_format: Option<String>, pub output_file: Option<String>, pub preset: Option<String>, pub threads: Option<usize>, pub rate_limit: Option<u32>, pub auto_persist: Option<bool>, pub network_timeout_ms: Option<u64>, pub network_max_retries: Option<usize>, pub network_request_delay_ms: Option<u64>, pub network_dns_resolver: Option<String>, pub network_dns_timeout_ms: Option<u64>, pub web_user_agent: Option<String>, pub web_follow_redirects: Option<bool>, pub web_max_redirects: Option<usize>, pub web_verify_ssl: Option<bool>, pub web_headers: HashMap<String, String>, pub web_timeout_secs: Option<u64>, pub recon_subdomain_wordlist: Option<String>, pub recon_passive_only: Option<bool>, pub recon_dns_timeout_ms: Option<u64>, pub db_dir: Option<String>, pub db_auto_name: Option<bool>, pub db_auto_persist: Option<bool>, pub db_format_version: Option<u32>, pub wordlists: HashMap<String, String>, pub credentials: HashMap<String, HashMap<String, String>>, pub commands: HashMap<String, HashMap<String, String>>, pub custom: HashMap<String, String>,
}
Parsed configuration from .reddb.yaml

Fields

verbose: Option<bool>no_color: Option<bool>output_format: Option<String>output_file: Option<String>preset: Option<String>threads: Option<usize>rate_limit: Option<u32>auto_persist: Option<bool>network_timeout_ms: Option<u64>network_max_retries: Option<usize>network_request_delay_ms: Option<u64>network_dns_resolver: Option<String>network_dns_timeout_ms: Option<u64>web_user_agent: Option<String>web_follow_redirects: Option<bool>web_max_redirects: Option<usize>web_verify_ssl: Option<bool>web_headers: HashMap<String, String>web_timeout_secs: Option<u64>recon_subdomain_wordlist: Option<String>recon_passive_only: Option<bool>recon_dns_timeout_ms: Option<u64>db_dir: Option<String>db_auto_name: Option<bool>db_auto_persist: Option<bool>db_format_version: Option<u32>wordlists: HashMap<String, String>credentials: HashMap<String, HashMap<String, String>>commands: HashMap<String, HashMap<String, String>>custom: HashMap<String, String>

Implementations

Source

impl YamlConfig

pub fn load_from_cwd_cached() -> &'static YamlConfig

Load from current directory once and cache the result.

pub fn load<P>(path: P) -> Result<YamlConfig, String>
where P: AsRef<Path>,

Load config from file

pub fn load_from_cwd() -> Option<YamlConfig>

Try to load from current directory

pub fn get_command_flag( &self, domain: &str, resource: &str, verb: &str, flag: &str, ) -> Option<String>

Get command-specific flag value Tries: domain.resource.verb -> domain.resource -> domain

pub fn command_flags( &self, domain: &str, resource: &str, verb: &str, ) -> HashMap<String, String>

Collect all command-level flags (domain/resource/verb) with specificity overrides.

pub fn has_command_flag( &self, domain: &str, resource: &str, verb: &str, flag: &str, ) -> bool

Check if command flag is set to true

pub fn get_credential(&self, service: &str, key: &str) -> Option<String>

Get a credential value for a given service and key