pub struct Uuid(/* private fields */);Implementations
Sourceimpl Uuid
impl Uuid
pub fn new_v4() -> Uuid
Sourcepub fn new_v7() -> Uuid
pub fn new_v7() -> Uuid
UUID v7: time-sortable. Bytes 0-5 = 48-bit Unix ms timestamp, byte 6 = version 7 nibble + 4 rand bits, byte 8 = variant 10xx, rest random. Monotonic within the same millisecond is not guaranteed — callers that need strict monotonicity should add a sequence counter.
Sourcepub fn parse_str(s: &str) -> Result<Uuid, UuidParseError>
pub fn parse_str(s: &str) -> Result<Uuid, UuidParseError>
Parse a hyphenated UUID string (xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx).
pub fn as_bytes(&self) -> &[u8; 16]