pub struct BinaryBulkInsertRequest {
pub collection: String,
pub field_names: Vec<String>,
pub rows: Vec<BinaryRow>,
}Expand description
Binary bulk insert — zero JSON overhead. Each BinaryRow has typed values sent as protobuf native types (no string serialization/parsing).
Fields
collection: Stringfield_names: Vec<String>column names (sent once for all rows)
rows: Vec<BinaryRow>Trait Implementations
Sourceimpl Clone for BinaryBulkInsertRequest
impl Clone for BinaryBulkInsertRequest
Sourcefn clone(&self) -> BinaryBulkInsertRequest
fn clone(&self) -> BinaryBulkInsertRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BinaryBulkInsertRequest
impl Debug for BinaryBulkInsertRequest
Sourceimpl Default for BinaryBulkInsertRequest
impl Default for BinaryBulkInsertRequest
Sourcefn default() -> BinaryBulkInsertRequest
fn default() -> BinaryBulkInsertRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for BinaryBulkInsertRequest
impl Message for BinaryBulkInsertRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BinaryBulkInsertRequest
impl PartialEq for BinaryBulkInsertRequest
Sourcefn eq(&self, other: &BinaryBulkInsertRequest) -> bool
fn eq(&self, other: &BinaryBulkInsertRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BinaryBulkInsertRequest