pub struct KvWatchEvent {
pub key: String,
pub op: String,
pub before_json: String,
pub after_json: String,
pub lsn: u64,
pub committed_at: u64,
pub dropped_event_count: u64,
}Fields
key: Stringop: Stringbefore_json: Stringafter_json: Stringlsn: u64committed_at: u64dropped_event_count: u64Trait Implementations
Sourceimpl Clone for KvWatchEvent
impl Clone for KvWatchEvent
Sourcefn clone(&self) -> KvWatchEvent
fn clone(&self) -> KvWatchEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KvWatchEvent
impl Debug for KvWatchEvent
Sourceimpl Default for KvWatchEvent
impl Default for KvWatchEvent
Sourcefn default() -> KvWatchEvent
fn default() -> KvWatchEvent
Returns the “default value” for a type. Read more
Sourceimpl Hash for KvWatchEvent
impl Hash for KvWatchEvent
Sourceimpl Message for KvWatchEvent
impl Message for KvWatchEvent
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for KvWatchEvent
impl PartialEq for KvWatchEvent
Sourcefn eq(&self, other: &KvWatchEvent) -> bool
fn eq(&self, other: &KvWatchEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for KvWatchEvent
impl StructuralPartialEq for KvWatchEvent