pub struct PrepareQueryReply {
pub prepared_id: u64,
pub parameter_count: u32,
}Fields
prepared_id: u64parameter_count: u32Trait Implementations
Sourceimpl Clone for PrepareQueryReply
impl Clone for PrepareQueryReply
Sourcefn clone(&self) -> PrepareQueryReply
fn clone(&self) -> PrepareQueryReply
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PrepareQueryReply
impl Debug for PrepareQueryReply
Sourceimpl Default for PrepareQueryReply
impl Default for PrepareQueryReply
Sourcefn default() -> PrepareQueryReply
fn default() -> PrepareQueryReply
Returns the “default value” for a type. Read more
Sourceimpl Hash for PrepareQueryReply
impl Hash for PrepareQueryReply
Sourceimpl Message for PrepareQueryReply
impl Message for PrepareQueryReply
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PrepareQueryReply
impl PartialEq for PrepareQueryReply
Sourcefn eq(&self, other: &PrepareQueryReply) -> bool
fn eq(&self, other: &PrepareQueryReply) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for PrepareQueryReply
impl Eq for PrepareQueryReply
impl StructuralPartialEq for PrepareQueryReply