pub struct StaleTermFenced {
pub boundary: FenceBoundary,
pub incoming_term: u64,
pub current_term: u64,
}Expand description
Why the term fence refused a message: the incoming term is behind the current term, so the sender is a deposed primary on a superseded timeline.
Fields
boundary: FenceBoundaryincoming_term: u64current_term: u64Trait Implementations
Sourceimpl Clone for StaleTermFenced
impl Clone for StaleTermFenced
Sourcefn clone(&self) -> StaleTermFenced
fn clone(&self) -> StaleTermFenced
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for StaleTermFenced
Sourceimpl Debug for StaleTermFenced
impl Debug for StaleTermFenced
Sourceimpl Display for StaleTermFenced
impl Display for StaleTermFenced
impl Eq for StaleTermFenced
Sourceimpl Error for StaleTermFenced
impl Error for StaleTermFenced
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for StaleTermFenced
impl PartialEq for StaleTermFenced
Sourcefn eq(&self, other: &StaleTermFenced) -> bool
fn eq(&self, other: &StaleTermFenced) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for StaleTermFenced