pub type MemberId = String;Expand description
Stable identity of a cluster member, matching the election membership id
(super::election::Member::id) and the replica/ack id namespace.
Aliased Type
pub struct MemberId { /* private fields */ }pub type MemberId = String;Stable identity of a cluster member, matching the election membership id
(super::election::Member::id) and the replica/ack id namespace.
pub struct MemberId { /* private fields */ }