Module lock_manager

Module lock_manager 

Intent lock management for runtime dispatch.

This is the live runtime lock manager used by dispatch-time collection and DDL locking. It is deliberately separate from the retired transaction coordinator modules described by ADR 0065.

Structs

LockConfig
Lock manager configuration
LockManager
Lock manager for coordinating transaction locks
LockStats
Lock manager statistics
LockWaiter
Lock waiter information

Enums

LockMode
Lock modes
LockResult
Lock request result

Type Aliases

TxnId
Transaction ID type