ScheduleOutcome

Enum ScheduleOutcome 

pub enum ScheduleOutcome {
    Queued,
    DroppedQueueFull {
        evicted_oldest: bool,
    },
}
Result of AsyncPromotionPool::schedule.

Variants



Queued

Request accepted into the queue.



DroppedQueueFull

Queue was full. evicted_oldest = true means we dropped the oldest pending request to admit this one. evicted_oldest = false means the queue was so contended even the eviction pop failed and this request was dropped instead.

Fields

evicted_oldest: bool