pub struct PromotionRequest {
pub namespace: String,
pub key: String,
pub bytes: Arc<[u8]>,
pub policy: BlobCachePolicy,
}Expand description
A single async promotion request handed to the pool by BlobCache::get
(or, in tests, by the test harness).
bytes is Arc<[u8]> so that the same buffer the caller is returning
to the user is shared zero-copy with the L1 promotion.
Fields
namespace: Stringkey: Stringbytes: Arc<[u8]>policy: BlobCachePolicyTrait Implementations
Sourceimpl Clone for PromotionRequest
impl Clone for PromotionRequest
Sourcefn clone(&self) -> PromotionRequest
fn clone(&self) -> PromotionRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for PromotionRequest
impl RefUnwindSafe for PromotionRequest
impl Send for PromotionRequest
impl Sync for PromotionRequest
impl Unpin for PromotionRequest
impl UnsafeUnpin for PromotionRequest
impl UnwindSafe for PromotionRequest