pub struct PageEncryptor { /* private fields */ }Expand description
Handles page encryption/decryption
Implementations
Sourceimpl PageEncryptor
impl PageEncryptor
Sourcepub fn new(key: SecureKey) -> PageEncryptor
pub fn new(key: SecureKey) -> PageEncryptor
Create a new page encryptor
Sourcepub fn encrypt(&self, page_id: u32, plaintext: &[u8]) -> Vec<u8> ⓘ
pub fn encrypt(&self, page_id: u32, plaintext: &[u8]) -> Vec<u8> ⓘ
Encrypt a page
Layout:
[Nonce (12 bytes)] [Ciphertext (N bytes)] [Tag (16 bytes)]
The plaintext size N will result in an output of size N + 28 bytes.
The caller is responsible for ensuring the plaintext fits within the
target page size (e.g., passing 4068 bytes to get a 4096 byte page).