pub struct SubqueryRewrite {
pub derived_alias: String,
pub join_type: RewriteJoinType,
pub inner_select: Vec<String>,
pub group_by: Vec<String>,
pub join_on: Vec<(String, String)>,
pub result_col: Option<String>,
}Expand description
Represents a rewrite of a correlated subquery to a join
Fields
derived_alias: StringAlias for the derived table
join_type: RewriteJoinTypeJoin type to use
inner_select: Vec<String>Columns to select from inner query (for the derived table)
group_by: Vec<String>GROUP BY columns for the derived table (if aggregation)
join_on: Vec<(String, String)>Join condition (outer_col = derived_alias.inner_col pairs)
result_col: Option<String>Column in derived table that replaces the subquery result