pub enum CanonicalKeyFamily {
Show 47 variants
Null,
Boolean,
Integer,
BigInt,
UnsignedInteger,
Float,
Text,
Blob,
Timestamp,
Duration,
IpAddr,
MacAddr,
Json,
Uuid,
NodeRef,
EdgeRef,
VectorRef,
RowRef,
Color,
Email,
Url,
Phone,
Semver,
Cidr,
Date,
Time,
Decimal,
EnumValue,
TimestampMs,
Ipv4,
Ipv6,
Subnet,
Port,
Latitude,
Longitude,
GeoPoint,
Country2,
Country3,
Lang2,
Lang5,
Currency,
ColorAlpha,
KeyRef,
DocRef,
TableRef,
PageRef,
Password,
}Expand description
Stable key family for ordered secondary indexes.
Families are intentionally narrow: range pushdown is only considered safe when all indexed values in a column belong to the same family.
Variants
Null
Boolean
Integer
BigInt
UnsignedInteger
Float
Text
Blob
Timestamp
Duration
IpAddr
MacAddr
Json
Uuid
NodeRef
EdgeRef
VectorRef
RowRef
Color
Url
Phone
Semver
Cidr
Date
Time
Decimal
EnumValue
TimestampMs
Ipv4
Ipv6
Subnet
Port
Latitude
Longitude
GeoPoint
Country2
Country3
Lang2
Lang5
Currency
ColorAlpha
KeyRef
DocRef
TableRef
PageRef
Password