pub struct LayoutToggles {
pub dedicated_wal_dir: bool,
pub dedicated_index_dir: bool,
pub dedicated_cache_dir: bool,
pub dedicated_snapshot_dir: bool,
pub dedicated_blob_dir: bool,
pub dedicated_temp_dir: bool,
pub dedicated_metrics_dir: bool,
}Expand description
Fully expanded layout toggles after applying a preset and overrides.
Fields
dedicated_wal_dir: booldedicated_index_dir: booldedicated_cache_dir: booldedicated_snapshot_dir: booldedicated_blob_dir: booldedicated_temp_dir: booldedicated_metrics_dir: boolTrait Implementations
Sourceimpl Clone for LayoutToggles
impl Clone for LayoutToggles
Sourcefn clone(&self) -> LayoutToggles
fn clone(&self) -> LayoutToggles
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LayoutToggles
impl Debug for LayoutToggles
Sourceimpl<'de> Deserialize<'de> for LayoutToggles
impl<'de> Deserialize<'de> for LayoutToggles
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<LayoutToggles, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<LayoutToggles, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for LayoutToggles
impl PartialEq for LayoutToggles
Sourcefn eq(&self, other: &LayoutToggles) -> bool
fn eq(&self, other: &LayoutToggles) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for LayoutToggles
impl Serialize for LayoutToggles
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for LayoutToggles
impl Eq for LayoutToggles
impl StructuralPartialEq for LayoutToggles