pub enum StreamError {
AlreadyExists {
scope: StreamScope,
name: String,
},
NotFound {
scope: StreamScope,
name: String,
},
CrossTenantDenied {
principal_tenant: Option<String>,
target: StreamScope,
stream: String,
},
}Expand description
Errors surfaced by the stream registry.
Variants
AlreadyExists
create_stream was called for a (scope, name) pair that
already has a stream.
NotFound
An op targeted a stream that has not been created.
CrossTenantDenied
The principal tried to address a stream outside their own
tenant without the stream:cross-tenant capability.