UpdateWhereBuilder

Struct UpdateWhereBuilder 

pub struct UpdateWhereBuilder<'db, T, F, SE, ST>
where F: Fn(&T) -> bool + Send + Sync + 'static,
{ /* private fields */ }
Builder for closure-based bulk updates, returned by RedDb::update_where.

Select documents with .filter (set at construction), cap with .limit(), provide the transformation with .with(), then execute via .exec() or .returning().

Implementations

Source

impl<'db, T, F, SE, ST> UpdateWhereBuilder<'db, T, F, SE, ST>
where F: Fn(&T) -> bool + Send + Sync + 'static, SE: Serializer + Debug, for<'de> ST: Storage + Debug + Send + Sync + 'static, for<'de> T: Serialize + Deserialize<'de> + Debug + Clone + PartialEq + Send + Sync,

pub fn limit(self, n: usize) -> Self

Stop after updating at most n documents.

pub async fn exec<G>(self, transform: G) -> Result<usize, RedDbError>
where G: Fn(T) -> T + Send + Sync,

Execute the update using transform and return the count of updated documents.

pub async fn returning<G>( self, transform: G, ) -> Result<Vec<Document<T>>, RedDbError>
where G: Fn(T) -> T + Send + Sync,

Execute the update using transform and return the updated documents.