pub struct StreamCancelRequest {
pub reason: Option<String>,
}Expand description
Parsed StreamCancel payload. The body is optional — clients
may send an empty payload to cancel without a reason.
Fields
reason: Option<String>Trait Implementations
Sourceimpl Clone for StreamCancelRequest
impl Clone for StreamCancelRequest
Sourcefn clone(&self) -> StreamCancelRequest
fn clone(&self) -> StreamCancelRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StreamCancelRequest
impl Debug for StreamCancelRequest
Sourceimpl Default for StreamCancelRequest
impl Default for StreamCancelRequest
Sourcefn default() -> StreamCancelRequest
fn default() -> StreamCancelRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for StreamCancelRequest
impl PartialEq for StreamCancelRequest
Sourcefn eq(&self, other: &StreamCancelRequest) -> bool
fn eq(&self, other: &StreamCancelRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for StreamCancelRequest
impl StructuralPartialEq for StreamCancelRequest