pub struct EscapedFor { /* private fields */ }Expand description
Output of Tainted::escape_for. Carries the boundary it was
escaped for so a header setter can statically refuse a value that
was escaped for a log line, and vice versa.
Implementations