Intent lock management for runtime dispatch.
This is the live runtime lock manager used by dispatch-time collection and DDL locking. It is deliberately separate from the retired transaction coordinator modules described by ADR 0065.
Structs
- Lock
Config - Lock manager configuration
- Lock
Manager - Lock manager for coordinating transaction locks
- Lock
Stats - Lock manager statistics
- Lock
Waiter - Lock waiter information
Enums
- Lock
Mode - Lock modes
- Lock
Result - Lock request result
Type Aliases
- TxnId
- Transaction ID type